@@ -1,3 +1,5 @@
+
+#' @export
 ## Copyright (C) 2005,2006,2009  Antonio, Fabio Di Narzo
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -316,9 +318,9 @@ pooledAIC <- function(parms) {
     if(hpc=="none"){ 
       computedCriterion <- mapply(SSR_1thresh, gam1=IDS[,2],thDelay=IDS[,1],MoreArgs=list(xx=xx,yy=yy,trans=z, ML=ML, MH=MH, const=const,trim=trim, fun=funBuild))
     } else {
-      computedCriterion <- foreach(i = th, .combine="c") %:% foreach(j = thDelay, .combine="c") %dopar% {
-	 SSR_1thresh(gam1=i,thDelay=j,xx=xx,yy=yy,trans=z, ML=ML, MH=MH, const=const,trim=trim, fun=funBuild)
-      }
+      computedCriterion <- foreach(i = th, .combine="c", .export="SSR_1thresh") %:% 
+        foreach(j = thDelay, .combine="c", .export="SSR_1thresh") %dopar% 
+        SSR_1thresh(gam1=i,thDelay=j,xx=xx,yy=yy,trans=z, ML=ML, MH=MH, const=const,trim=trim, fun=funBuild)
     }
   }
 
@@ -457,6 +459,7 @@ class(ret)<-"selectSETAR"
 return(ret)
 }
 
+#' @S3method print selectSETAR
 print.selectSETAR<-function(x,...){
   cat("Results of the grid search for 1 threshold\n")
   if(x$criterion=="SSR"){
@@ -490,7 +493,7 @@ print.selectSETAR<-function(x,...){
 }
 
 
-
+#' @S3method plot selectSETAR
 plot.selectSETAR<-function(x,...){
   if(x$criterion!="SSR")
     stop("Currently only implemented for criterion SSR")
